@@ -199,10 +199,10 @@ gboolean jammo_miditrack_view_zoom_to_fit(JammoMiditrackView* miditrack_view, gf
 
 	//New values for each existing note
 	TangleWidget* widget = TANGLE_WIDGET(miditrack_view);
-	GList* children;
+	TangleActorIterator actor_iterator;
 	ClutterActor* actor;
-	for (children = tangle_widget_get_children_readonly(widget); children; children = children->next) {
-		actor = CLUTTER_ACTOR(children->data);
+	
+	for (tangle_widget_initialize_actor_iterator(widget, &actor_iterator); (actor = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
 		clutter_actor_set_width(actor,ratio_x*clutter_actor_get_width(actor)); //old value * ratio_x
 		clutter_actor_set_x(actor,ratio_x*clutter_actor_get_x(actor));  //old value * ratio_x
 		clutter_actor_set_height(actor,new_height); //Height of note is always same than height of slot.
@@ -250,7 +250,8 @@ gboolean jammo_miditrack_view_get_editing_enabled(JammoMiditrackView* miditrack_
 }
 
 void jammo_miditrack_view_set_editing_enabled(JammoMiditrackView* miditrack_view, gboolean editing_enabled) {
-	GList* children;
+	TangleActorIterator actor_iterator;
+	ClutterActor* child;
 
 	g_return_if_fail(JAMMO_IS_MIDITRACK_VIEW(miditrack_view));
 
@@ -258,8 +259,9 @@ void jammo_miditrack_view_set_editing_enabled(JammoMiditrackView* miditrack_view
 		miditrack_view->priv->editing_enabled = editing_enabled;
 		
 		clutter_actor_meta_set_enabled(CLUTTER_ACTOR_META(tangle_actor_get_action_by_type(CLUTTER_ACTOR(miditrack_view), TANGLE_TYPE_DROP_ACTION)), editing_enabled);
-		for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(miditrack_view)); children; children = children->next) {
-			clutter_actor_meta_set_enabled(CLUTTER_ACTOR_META(tangle_actor_get_action_by_type(CLUTTER_ACTOR(children->data), TANGLE_TYPE_DRAG_ACTION)), editing_enabled);
+	
+		for (tangle_widget_initialize_actor_iterator(TANGLE_WIDGET(miditrack_view), &actor_iterator); (child = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
+			clutter_actor_meta_set_enabled(CLUTTER_ACTOR_META(tangle_actor_get_action_by_type(child, TANGLE_TYPE_DRAG_ACTION)), editing_enabled);
 		}
 
 		g_object_notify(G_OBJECT(miditrack_view), "editing-enabled");
