@@ -19,7 +19,7 @@
 gems_group_info* gems_new_group_info(guint32 id, guint32 owner, gint16 type, gint16 size, gint16 spaces, gint16 theme, gboolean starttimer)
 {
 	gint i = 0;
-	gems_group_info* info = (gems_group_info*)g_malloc(sizeof(gems_group_info));
+	gems_group_info* info = g_new(gems_group_info,sizeof(gems_group_info));
 	
 	info->id = id;
 	info->owner = owner;
